indexing

   description: "Test Standard C buffer class."

   author: "Berend de Boer"
   date: "$Date: 2001/12/27 $"
   revision: "$Revision: #1 $"
   

class 

   TEST_BUFFER


inherit
   
   STDC_BASE
   

creation
   
   make

   
feature

   hello: STRING is "Hello World!"

   make is
      local
         buf,
         buf2: STDC_BUFFER
         byte: INTEGER
         c: CHARACTER
         i: INTEGER
         b1, b2: INTEGER
      do
         print ("testing Posix dynamic memory interface.%N")

         print ("Allocate 100 bytes.%N")
         create buf.allocate (100)
         print ("Deallocate it.%N")
         buf.deallocate

         print ("Allocate 100 bytes of zeroed out memory.%N")
         create buf.allocate_and_clear (100)
         print ("Resize it to 256 bytes.%N")
         buf.resize (256)
         print ("Resize it to 256 bytes.%N")
         
         print ("Set a byte.%N")
         buf.poke_uint8 (0, 16)
         byte := buf.peek_uint8 (0)
         if byte /= 16 then
            print ("!! Expected 16, got ")
            print (byte)
            print (".%N")
         end
         
         buf.poke_int8 (1, -1)
         byte := buf.peek_uint8 (1)
         if byte /= 255 then
            print ("!! Expected 255, got ")
            print (byte)
            print (".%N")
         end
         
         buf.poke_int8 (1, -127)
         byte := buf.peek_uint8 (1)
         if byte /= 129 then
            print ("!! Expected 129, got ")
            print (byte)
            print (".%N")
         end
         
         buf.poke_int8 (255, -128)
         byte := buf.peek_uint8 (255)
         if byte /= 128 then
            print ("!! Expected 128, got ")
            print (byte)
            print (".%N")
         end
         
         buf.poke_int8 (1, 1)
         byte := buf.peek_int8 (1)
         if byte /= 1 then
            print ("!! Expected 1, got ")
            print (byte)
            print (".%N")
         end
         
         buf.move (0, 1, 1)
         byte := buf.peek_uint8 (1)
         if byte /= 16 then
            print ("!! Expected 16, got ")
            print (byte)
            print (".%N")
         end
         
         c := '%/141/';
         buf.poke_character (0, c)
         byte := buf.peek_uint8 (0)
         if byte /= 141 then
            print ("!! Expected 141, got ")
            print (byte)
            print (".%N")
         end
         
         buf.poke_int32_little_endian (0, 16909060) -- 0x01020304
         i := buf.peek_int32_big_endian (0)
         if i /= 67305985 then -- 0x04030201
            print ("!! Expected 67305985, got ")
            print (i)
            print (".%N")
         end
         i := buf.peek_int32_little_endian (0)
         if i /= 16909060 then -- 0x04030201
            print ("!! Expected 16909060, got ")
            print (i)
            print (".%N")
         end
         
         buf.poke_int32_big_endian (6, 16909060) -- 0x01020304
         i := buf.peek_int32_big_endian (6)
         if i /= 16909060 then -- 0x04030201
            print ("!! Expected 16909060, got ")
            print (i)
            print (".%N")
         end
         i := buf.peek_int32_little_endian (6)
         if i /= 67305985 then -- 0x04030201
            print ("!! Expected 67305985, got ")
            print (i)
            print (".%N")
         end
         
         buf.poke_int16_little_endian (6, 258) -- 0x0102
         buf.poke_int16_big_endian (6, 258) -- 0x0102
         i := buf.peek_int16_big_endian (6)
         if i /= 258 then
            print ("!! Expected 258, got ")
            print (i)
            print (".%N")
         end
         i := buf.peek_int16_little_endian (6)
         if i /= 513 then -- 0x0201
            print ("!! Expected 513, got ")
            print (i)
            print (".%N")
         end
         
         buf.poke_int16_native (15, -1)
         i := buf.peek_uint16_native (15)
         if i /= 65535 then
            print ("!! Expected 65535, got ")
            print (i)
            print (".%N")
         end
         
         -- test copy_from
         print ("Test copy_from.%N")
         create buf2.allocate_and_clear (100)
         buf2.copy_from (buf, 0, 50, 4)
         i := buf2.peek_int32_little_endian (50)
         if i /= 16909060 then -- 0x04030201
            print ("!! Expected 67305985, got ")
            print (i)
            print (".%N")
         end
         
         -- test memset
         buf2.fill_at (10, 5, 55)
         b1 := buf2.peek_uint8 (10)
         b2 := buf2.peek_uint8 (14)
         if b1 /= 55 then
            print ("!! First byte should be 55.%N")
         end
         if b2 /= 55 then
            print ("!! First byte should be 55.%N")
         end
         
         print ("Deallocate the memory.%N")
         buf.deallocate
         
         -- test locate
         create buf.make_from_pointer (sh.string_to_pointer (hello), hello.count, False)
         i := buf.locate_character ('!', 5)
         if i /= 11 then
            print ("!! Should find ! at position 11.%N")
         end
         i := buf.locate_string ("Hello", 0)
         if i /= 0 then
            print ("!! Expected index 0 for locate_string.%N")
         end
         i := buf.locate_string ("Hello", 1)
         if i /= -1 then
            print ("!! Expected index -1 for locate_string.%N")
         end
         i := buf.locate_string ("ld!", 0)
         if i /= 9 then
            print ("!! Expected index 9 for locate_string.%N")
         end
         i := buf.locate_string ("ld!", 9)
         if i /= 9 then
            print ("!! Expected index 9 for locate_string.%N")
         end
         i := buf.locate_string ("ld!", 10)
         if i /= -1 then
            print ("!! Expected index -1 for locate_string.%N")
         end
         
         print ("End of Posix dynamic memory test.%N")
      end
   
end -- class TEST_BUFFER
