indexing

   description: "Test Posix file system class."

   author: "Berend de Boer"
   date: "$Date: 2001/12/27 $"
   revision: "$Revision: #1 $"

class TEST_P_FILE_SYSTEM

inherit

   POSIX_CURRENT_PROCESS

   POSIX_FILE_SYSTEM


creation

   make

feature

   make is
      local
         file: POSIX_TEXT_FILE
         stat: POSIX_STATUS
         perm: POSIX_PERMISSIONS
         command: POSIX_SHELL_COMMAND
         dir: POSIX_DIRECTORY
         i: INTEGER
         name: STRING
         tmpfile: POSIX_BINARY_FILE
         temp_status: POSIX_STATUS
      do
         print ("Test POSIX_FILE_SYSTEM%N")

         print ("The temporary directory: ")
         print (temporary_directory)
         print ("%N")

         test_directory

         create command.make ("/bin/ls -l *.tmp")

         name := "tmp.tmp"
         print ("Test accessibility of ")
         print (name)
         print (".%N")
         create tmpfile.create_read_write (name)
         tmpfile.close
         if is_existing (name) then
            print ("Is existing file.%N")
         else
            print ("!! Temporary file does not exist.%N")
         end
         if is_readable (name) then
            print ("Is real user ID readable file.%N")
         else
            print ("!! Temporary file is not real user ID readable.%N")
         end
         if is_writable (name) then
            print ("Is writable file.%N")
         else
            print ("!! Temporary file is not writable.%N")
         end
         if is_empty (name) then
            print ("Is empty file.%N")
         else
            print ("!! Temporary file is not empty.%N")
         end

         temp_status := status (name)
         print ("Last access time: ")
         print (temp_status.access_time)
         print ("%N")
         print ("Last change time: ")
         print (temp_status.change_time)
         print ("%N")
         print ("Last modification time: ")
         print (temp_status.modification_time)
         print ("%N")

         if temp_status.is_block_special then
            print ("!! Temporary file is a block device.%N")
         end
         if temp_status.is_character_special then
            print ("!! Temporary file is a character device.%N")
         end
         if temp_status.is_directory then
            print ("!! Temporary file is a directory.%N")
         end
         if temp_status.is_fifo then
            print ("!! Temporary file is a fifo.%N")
         end
         if not temp_status.is_regular_file then
            print ("!! Temporary file isn't a regular file.%N")
         end

         print ("Remove write permission.%N")
         set_read_only (name)

         if status (name).permissions.allow_write then
            print ("!! Is permission bit writable file.%N")
         else
            print ("Temporary file is not permission bit writable.%N")
         end
         if is_writable (name) then
            print ("!! Is still writable file (perhaps you're root).%N")
         else
            print ("Is no longer writable.%N")
         end

         if status (name).permissions.allow_owner_read then
            print ("Is permission bit readable file.%N")
         else
            print ("!! Temporary file is not permission bit readable.%N")
         end
         if status (name).permissions.allow_write then
            print ("!! Is permission bit writable file.%N")
         else
            print ("Temporary file is not permission bit writable.%N")
         end

         set_writable (name)
         remove_file (name)

         create tmpfile.create_read_write (name)
         tmpfile.close

         print ("Cache permission.%N")
         perm := status (name).permissions

         print ("Test if cache can be refreshed.%N")
         perm.refresh

         print ("Remove read permission.%N")
         perm := status (name).permissions
         perm.set_allow_read_write (False)
         perm.apply
         if is_readable (name) then
            print ("!! Is still readable file (perhaps you're root).%N")
         else
            print ("Is no longer readable.%N")
         end
         if perm.allow_write then
            print ("!! Is still writable file (perhaps you're root).%N")
         else
            print ("Is no longer writable.%N")
         end
         perm.set_allow_read_write (True)
         perm.apply
         if perm.allow_write then
            print ("Is writable again.%N")
         else
            print ("!! Is not writable file.%N")
         end
         touch (name)

         print ("Status info: %N")
         stat := status (name)
         print ("size: ")
         print (stat.size.out)
         print (".%N")
         print ("uid: ")
         print (stat.permissions.uid)
         print (".%N")

         remove_file (name)

         if not is_existing (name) then
            print ("Does not exist.%N")
         else
            print ("!! Temporary file still exists.%N")
         end

         print ("Test is_executable.%N")
         if is_executable ("/bin/sh") then
            print ("/bin/sh is executable file.%N")
         else
            print ("!! /bin/sh is not executable.%N")
         end

         print ("Create and remove a link.%N")
         create file.create_read_write ("file.tmp")
         file.close

         test_hard_link

         print ("Print something about the permissions.%N")
         perm := permissions("file.tmp")
         if perm.allow_group_read then
            print ("Group is allowed to read file.tmp.%N")
         else
            print ("Group is not allowed to read file.tmp.%N")
         end
         if perm.allow_anyone_read_write then
            print ("Anyone is allowed to write file.tmp.%N")
         else
            print ("Anyone is not allowed to write file.tmp.%N")
         end
         if perm.is_set_user_id then
            print ("Set user id is set.%N")
         else
            print ("Set user id is not set.%N")
         end

         print ("Change group to wheel.%N")
         if is_in_group (0) then
            perm.set_group_id (0)
            perm.apply
            perm.refresh
            if perm.group_id /= 0 then
               print ("!! Group not changed. It is: ")
               print (perm.group_id)
               print ("%N")
            else
               print ("Group changed.%N")
            end
         else
            print ("!! Works only if you're in wheel, and you're not.%N")
         end

         print ("Give anyone write permission.%N")
         perm.set_allow_anyone_read_write (True)
         perm.apply

         unlink ("link.tmp")
         if is_existing ("link.tmp") then
            print ("!! link.tmp is not removed.%N")
         else
            print ("link.tmp is removed.%N")
         end
         unlink ("file.tmp")
         if is_existing ("file.tmp") then
            print ("!! file.tmp is not removed.%N")
         else
            print ("file.tmp is removed.%N")
         end

         print ("Test directory reading.%N")
         from
            dir := browse_directory (".")
            dir.start
            i := 0
         until
            dir.exhausted
         loop
            i := i + 1
            print (dir.item)
            print ("%N")
            dir.forth
         end
         print ("Number of entries: ")
         print (i)
         print ("%N")

         print  ("End of test.%N")
      end


   test_directory is
      local
         dir: STRING
      do
         print ("Test directory functions%N")
         dir := getcwd
         chdir ("..")
         print ("Dir: ")
         print (getcwd)
         print (".%N")
         chdir (dir)
         print ("Dir: ")
         print (getcwd)
         print (".%N")
         if not equal(dir, getcwd) then
            print ("!! Directory is not the expected directory.%N")
         end
         mkdir ("abc")
         chdir ("abc")
         print ("Dir: ")
         print (getcwd)
         print (".%N")
         change_directory ("..")
         rename_to ("abc", "def")
         if not status("def").is_directory then
            print ("!! Temporary file is not a directory.%N")
         end
         rmdir ("def")
      end

   test_hard_link is
      local
         failed: BOOLEAN
      do
         if not failed then
            remove_file ("link.tmp")
            link ("file.tmp", "link.tmp")
            if is_readable ("link.tmp") then
               print ("link.tmp is a readable file.%N")
            else
               print ("!! link.tmp is not executable.%N")
            end
            unlink ("link.tmp")
         end
      rescue
         print ("!! error creating link: ")
         print (errno.message)
         print (" (probably not supported)%N")
         failed := True
         retry
      end

   test_fifo is
      local
         failed: BOOLEAN
      do
         if not failed then
            print ("Test make_fifo.%N")
            if is_existing ("berend.tmp") then
               unlink ("berend.tmp")
            end
            create_fifo ("berend.tmp", S_IRUSR + S_IWUSR)
            -- you can now read or write the fifo
            -- some other process should do the reverse
            if not status("berend.tmp").is_fifo then
               print ("!! Temporary file is not a fifo.%N")
            end
            unlink ("berend.tmp")
         end
      rescue
         print ("!! error creating fifo: ")
         print (errno.message)
         print (" (probably not supported)%N")
         failed := True
         retry
      end

end -- class TEST_P_FILE_SYSTEM
